@@ -262,7 +262,7 @@ int readHB_info(const char* filename, int* M, int* N, int* nz, char** Type,
                   &Ptrcrd, &Indcrd, &Valcrd, &Rhscrd, Rhstype);
     fclose(in_file);
     *Type = mat_type;
-    *(*Type+3) = (char) NULL;
+    *(*Type+3) = '\0';
     *M    = Nrow;
     *N    = Ncol;
     *nz   = Nnzero;
@@ -304,8 +304,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     if ( sscanf(line,"%*s") < 0 )
         IOHBTerminate("iohb.c: Null (or blank) first line of HB file.\n");
     (void) sscanf(line, "%72c%8[^\n]", Title, Key);
-    *(Key+8) = (char) NULL;
-    *(Title+72) = (char) NULL;
+    *(Key+8) = '\0';
+    *(Title+72) = '\0';
 
 /*  Second line:  */
     fgets(line, BUFSIZ, in_file);
@@ -340,10 +340,10 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     if ( sscanf(line, "%*16c%*16c%20c",Valfmt) != 1)
         IOHBTerminate("iohb.c: Invalid format info, line 4 of Harwell-Boeing file.\n");
     sscanf(line, "%*16c%*16c%*20c%20c",Rhsfmt);
-    *(Ptrfmt+16) = (char) NULL;
-    *(Indfmt+16) = (char) NULL;
-    *(Valfmt+20) = (char) NULL;
-    *(Rhsfmt+20) = (char) NULL;
+    *(Ptrfmt+16) = '\0';
+    *(Indfmt+16) = '\0';
+    *(Valfmt+20) = '\0';
+    *(Rhsfmt+20) = '\0';
 
 /*  (Optional) Fifth line: */
     if (*Rhscrd != 0 )
@@ -417,7 +417,7 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
 
     ThisElement = (char *) malloc(Ptrwidth+1);
     if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Ptrwidth) = (char) NULL;
+    *(ThisElement+Ptrwidth) = '\0';
     count=0;
     for (i=0;i<Ptrcrd;i++)
     {
@@ -440,7 +440,7 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
 
     ThisElement = (char *) malloc(Indwidth+1);
     if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Indwidth) = (char) NULL;
+    *(ThisElement+Indwidth) = '\0';
     count = 0;
     for (i=0;i<Indcrd;i++)
     {
@@ -469,7 +469,7 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
     ThisElement = (char *) malloc(Valwidth+1);
     if ( ThisElement == NULL )
       IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Valwidth) = (char) NULL;
+    *(ThisElement+Valwidth) = '\0';
     count = 0;
     for (i=0;i<Valcrd;i++)
     {
@@ -657,7 +657,7 @@ int readHB_aux_double(const char* filename, const char AuxType, double b[])
 
   ThisElement = (char *) malloc(Rhswidth+1);
   if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-  *(ThisElement+Rhswidth) = (char) NULL;
+  *(ThisElement+Rhswidth) = '\0';
   for (rhsi=0;rhsi<Nrhs;rhsi++) {
 
     for (i=0;i<Nentries;i++) {
@@ -770,7 +770,7 @@ int writeHB_mat_double(const char* filename, int M, int N,
          REprintf("Error: Cannot open file: %s\n",filename);
          return 0;
        }
-    } else out_file = stdout;
+    } /* else out_file = stdout; */
 
     if ( Ptrfmt == NULL ) Ptrfmt = "(8I10)";
     ParseIfmt(Ptrfmt,&Ptrperline,&Ptrwidth);
@@ -971,7 +971,7 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
 
     ThisElement = (char *) malloc(Ptrwidth+1);
     if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Ptrwidth) = (char) NULL;
+    *(ThisElement+Ptrwidth) = '\0';
     count=0;
     for (i=0;i<Ptrcrd;i++)
     {
@@ -994,7 +994,7 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
 
     ThisElement = (char *) malloc(Indwidth+1);
     if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Indwidth) = (char) NULL;
+    *(ThisElement+Indwidth) = '\0';
     count = 0;
     for (i=0;i<Indcrd;i++)
     {
@@ -1022,7 +1022,7 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
 
     ThisElement = (char *) malloc(Valwidth+1);
     if ( ThisElement == NULL ) IOHBTerminate("Insufficient memory for ThisElement.");
-    *(ThisElement+Valwidth) = (char) NULL;
+    *(ThisElement+Valwidth) = '\0';
     count = 0;
     for (i=0;i<Valcrd;i++)
     {
@@ -1357,7 +1357,7 @@ int writeHB_mat_char(const char* filename, int M, int N,
          REprintf("Error: Cannot open file: %s\n",filename);
          return 0;
        }
-    } else out_file = stdout;
+    } /* else out_file = stdout; */
 
     if ( Ptrfmt == NULL ) Ptrfmt = "(8I10)";
     ParseIfmt(Ptrfmt,&Ptrperline,&Ptrwidth);
@@ -1536,7 +1536,7 @@ int ParseRfmt(char* fmt, int* perline, int* width, int* prec, int* flag)
        while ( strchr(tmp2+1,')') != NULL ) {
           tmp2 = strchr(tmp2+1,')');
        }
-       *(tmp2+1) = (int) NULL;
+       *(tmp2+1) = 0; /* was (int) NULL; */
     }
     if (strchr(fmt,'P') != NULL)  /* Remove any scaling factor, which */
     {                             /* affects output only, not input */
@@ -1546,11 +1546,11 @@ int ParseRfmt(char* fmt, int* perline, int* width, int* prec, int* flag)
         tmp3 = strchr(fmt,'(')+1;
         len = tmp-tmp3;
         tmp2 = tmp3;
-        while ( *(tmp2+len) != (int) NULL ) {
+        while ( *(tmp2+len) != 0) { /* was (int) NULL ) { */
            *tmp2=*(tmp2+len);
            tmp2++;
         }
-        *(strchr(fmt,')')+1) = (int) NULL;
+        *(strchr(fmt,')')+1) = 0; /* was (int) NULL; */
       }
     }
     if (strchr(fmt,'E') != NULL) {
@@ -1584,7 +1584,7 @@ char* substr(const char* S, const int pos, const int len)
     SubS = (char *)malloc(len+1);
     if ( SubS == NULL ) IOHBTerminate("Insufficient memory for SubS.");
     for (i=0;i<len;i++) SubS[i] = S[pos+i];
-    SubS[len] = (char) NULL;
+    SubS[len] = '\0';
     } else {
       SubS = NULL;
     }
@@ -1603,8 +1603,8 @@ void upcase(char* S)
 
 void IOHBTerminate(char* message)
 {
-//   fprintf(stderr,message);
-//   exit(1);
+/*   fprintf(stderr,message);
+**   exit(1); */
     error(message);
 }
 
